@@ -46,6 +46,12 @@
 #include <stdlib.h>
 #endif
 
+#ifdef HAVE___ATTRIBUTE__
+# define ATTRIB_NORETURN __attribute__ ((__noreturn__))
+#else
+# define ATTRIB_NORETURN
+#endif
+
 /* From execute.c */
 void stop_execution (int);
 unsigned char byte (program_counter *pc_);
@@ -83,7 +89,7 @@ void yyerror (const char *str ,...);
 void ct_warn (const char *mesg ,...);
 void rt_error (const char *mesg ,...);
 void rt_warn (const char *mesg ,...);
-void bc_exit (int);
+void bc_exit (int) ATTRIB_NORETURN;
 
 /* From load.c */
 void init_load (void);
